@@ -1,4 +1,4 @@
-# Copyright 2016-2022 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
+# Copyright 2016-2023 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
 # ReFrame Project Developers. See the top-level LICENSE file for details.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -111,11 +111,6 @@ class FixtureRegistry:
             p.fullname: {e.name for e in p.environs} for p in sys_part
         }
 
-        # Compact naming switch
-        self._hash = runtime.runtime().get_option(
-            'general/0/compact_test_names'
-        )
-
         # Store the system name for name-mangling purposes
         self._sys_name = runtime.runtime().system.name
 
@@ -177,10 +172,7 @@ class FixtureRegistry:
                 (f'%{k}={utils.toalphanum(str(v))}' for k, v
                  in sorted(variables.items()))
             )
-            if self._hash:
-                vname = '_' + sha256(vname.encode('utf-8')).hexdigest()[:8]
-
-            fname += vname
+            fname += '_' + sha256(vname.encode('utf-8')).hexdigest()[:8]
 
         # Select only the valid partitions
         try:
@@ -312,7 +304,6 @@ class FixtureRegistry:
                     'valid_systems': part,
                     **variables
                 }
-
                 try:
                     # Instantiate the fixture
                     inst = cls(variant_num=varnum, fixt_name=name,
@@ -330,17 +321,15 @@ class FixtureRegistry:
 
         return ret
 
+    def uninst_tests(self):
+        '''Get the uninstantiated tests of this registry'''
+        return self._registry.keys()
+
     def _filter_valid_partitions(self, candidate_parts):
         return [p for p in candidate_parts if p in self._env_by_part]
 
     def _filter_valid_environs(self, part, candidate_environs):
-        ret = []
-        environs = self._env_by_part[part]
-        for e in candidate_environs:
-            if e in environs:
-                ret.append(e)
-
-        return ret
+        return [e for e in cadidate_environs if e in self._env_by_part[part]]
 
     def _is_registry(self, other):
         if not isinstance(other, FixtureRegistry):
