@@ -1,4 +1,4 @@
-# Copyright 2016-2022 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
+# Copyright 2016-2023 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
 # ReFrame Project Developers. See the top-level LICENSE file for details.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -53,26 +53,44 @@ def list_checks(testcases, printer, detailed=False, concretized=False):
     printer.info('[List of matched checks]')
     unique_checks = set()
 
-    def dep_lines(u, *, prefix, depth=0, lines=None, printed=None):
+    def dep_lines(u, *, prefix, depth=0, lines=None, printed=None,
+                  fixt_vars=None):
         if lines is None:
             lines = []
 
         if printed is None:
             printed = set(unique_checks)
 
+        fixt_to_vars = {}
+        for fixt_name, fixt in u.check._rfm_fixture_space.items():
+            key = f'{fixt.cls.__name__}#{fixt.scope}'
+            fixt_to_vars.setdefault(key, [])
+            fixt_to_vars[key].append(fixt_name)
+
         adj = u.deps
         for v in adj:
+            if v.check.is_fixture():
+                fixture_scope = v.check._rfm_fixt_data.scope
+                key = f'{type(v.check).__name__}#{fixture_scope}'
+                fixture_vars = fixt_to_vars[key]
+            else:
+                fixture_vars = None
+                unique_checks.add(v.check.unique_name)
+
             if concretized or (not concretized and
                                v.check.unique_name not in printed):
                 dep_lines(v, prefix=prefix + 2*' ', depth=depth+1,
-                          lines=lines, printed=printed)
-
-            printed.add(v.check.unique_name)
-            if not v.check.is_fixture():
-                unique_checks.add(v.check.unique_name)
+                          lines=lines, printed=printed,
+                          fixt_vars=fixture_vars)
 
         if depth:
-            name_info = f'{u.check.display_name} /{u.check.hashcode}'
+            if fixt_vars:
+                fmt_fixt_vars = " '"
+                fmt_fixt_vars += " '".join(fixt_vars)
+            else:
+                fmt_fixt_vars = ''
+
+            name_info = f'{u.check.display_name}{fmt_fixt_vars} /{u.check.hashcode}'
             tc_info = ''
             details = ''
             if concretized:
@@ -368,6 +386,10 @@ def main():
         '-r', '--run', action='store_true',
         help='Run the selected checks'
     )
+    action_options.add_argument(
+        '--dry-run', action='store_true',
+        help='Dry run the tests without submitting them for execution'
+    )
 
     # Run options
     run_options.add_argument(
@@ -725,16 +747,22 @@ def main():
 
         # Update options from the selected execution mode
         if options.mode:
-            mode_args = site_config.get(f'modes/@{options.mode}/options')
+            mode = site_config.get(f'modes/@{options.mode}')
+            if mode is None:
+                printer.warning(f'invalid mode: {options.mode!r}; ignoring...')
+            else:
+                mode_args = site_config.get(f'modes/@{options.mode}/options')
 
-            # We lexically split the mode options, because otherwise spaces
-            # will be treated as part of the option argument; see GH bug #1554
-            mode_args = list(itertools.chain.from_iterable(shlex.split(m)
-                                                           for m in mode_args))
-            # Parse the mode's options and reparse the command-line
-            options = argparser.parse_args(mode_args)
-            options = argparser.parse_args(namespace=options.cmd_options)
-            options.update_config(site_config)
+                # We lexically split the mode options, because otherwise spaces
+                # will be treated as part of the option argument;
+                # see GH bug #1554
+                mode_args = list(
+                    itertools.chain.from_iterable(shlex.split(m)
+                                                  for m in mode_args))
+                # Parse the mode's options and reparse the command-line
+                options = argparser.parse_args(mode_args)
+                options = argparser.parse_args(namespace=options.cmd_options)
+                options.update_config(site_config)
 
         logging.configure_logging(site_config)
     except (OSError, errors.ConfigError) as e:
@@ -878,6 +906,9 @@ def main():
         else:
             external_vars[lhs] = rhs
 
+    if options.dry_run:
+        external_vars['_rfm_dry_run'] = '1'
+
     loader = RegressionCheckLoader(check_search_path,
                                    check_search_recursive,
                                    external_vars,
@@ -893,6 +924,7 @@ def main():
         'config_files': rt.site_config.sources,
         'data_version': runreport.DATA_VERSION,
         'hostname': socket.gethostname(),
+        'log_files': logging.log_files(),
         'prefix_output': rt.output_prefix,
         'prefix_stage': rt.stage_prefix,
         'user': osext.osuser(),
@@ -919,7 +951,7 @@ def main():
     print_infoline('stage directory', repr(session_info['prefix_stage']))
     print_infoline('output directory', repr(session_info['prefix_output']))
     print_infoline('log files',
-                   ', '.join(repr(s) for s in logging.log_files()))
+                   ', '.join(repr(s) for s in session_info['log_files']))
     printer.info('')
     try:
         logging.getprofiler().enter_region('test processing')
@@ -1148,10 +1180,11 @@ def main():
             )
             sys.exit(0)
 
-        if not options.run:
+        if not options.run and not options.dry_run:
             printer.error("No action option specified. Available options:\n"
                           "  - `-l'/`-L' for listing\n"
                           "  - `-r' for running\n"
+                          "  - `--dry-run' for dry running\n"
                           "  - `--list-tags' for listing unique test tags\n"
                           "  - `--ci-generate' for generating a CI pipeline\n"
                           f"Try `{argparser.prog} -h' for more options.")
@@ -1248,6 +1281,7 @@ def main():
         exec_policy.keep_stage_files = site_config.get(
             'general/0/keep_stage_files'
         )
+        exec_policy.dry_run_mode = options.dry_run
         try:
             errmsg = "invalid option for --flex-alloc-nodes: '{0}'"
             sched_flex_alloc_nodes = int(options.flex_alloc_nodes)
