@@ -1,4 +1,4 @@
-# Copyright 2016-2022 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
+# Copyright 2016-2023 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
 # ReFrame Project Developers. See the top-level LICENSE file for details.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -14,7 +14,6 @@ import os
 import sys
 import traceback
 
-import reframe.core.fields as fields
 import reframe.utility as util
 import reframe.utility.osext as osext
 from reframe.core.exceptions import NameConflictError, is_severe, what
@@ -133,29 +132,6 @@ class RegressionCheckLoader:
     def recurse(self):
         return self._recurse
 
-    def _set_defaults(self, test_registry):
-        if test_registry is None:
-            return
-
-        self._unset_vars = {}
-        for test in test_registry:
-            for name, val in self._external_vars.items():
-                if '.' in name:
-                    testname, varname = name.split('.', maxsplit=1)
-                else:
-                    testname, varname = test.__name__, name
-
-                if testname == test.__name__:
-                    # Treat special values
-                    if val == '@none':
-                        val = None
-                    else:
-                        val = fields.make_convertible(val)
-
-                    if not test.setvar(varname, val):
-                        self._unset_vars.setdefault(test.__name__, [])
-                        self._unset_vars[test.__name__].append(varname)
-
     def load_from_module(self, module):
         '''Load user checks from module.
 
@@ -164,10 +140,13 @@ class RegressionCheckLoader:
         are validated before return.
         '''
         registry = getattr(module, '_rfm_test_registry', None)
-        self._set_defaults(registry)
+        if registry:
+            self._unset_vars.update(registry.setvars(self._external_vars))
+
         reset_sysenv = self._skip_prgenv_check << 1 | self._skip_system_check
         if registry:
-            candidate_tests = registry.instantiate_all(reset_sysenv)
+            candidate_tests = registry.instantiate_all(reset_sysenv,
+                                                       self._external_vars)
         else:
             candidate_tests = []
 
@@ -177,17 +156,23 @@ class RegressionCheckLoader:
             if not self._validate_check(c):
                 continue
 
-            testfile = module.__file__
+            # Get the original filename in case of a different module name
+            if module.__name__ == c.__module__:
+                testfile = module.__file__
+            else:
+                testfile = inspect.getfile(c.__class__)
+
             try:
                 conflicted = self._loaded[c.unique_name]
             except KeyError:
                 self._loaded[c.unique_name] = testfile
                 final_tests.append(c)
             else:
-                raise NameConflictError(
-                    f'test {c.unique_name!r} from {testfile!r} '
-                    f'is already defined in {conflicted!r}'
-                )
+                if not c.is_fixture():
+                    raise NameConflictError(
+                        f'test {c.unique_name!r} from {testfile!r} '
+                        f'is already defined in {conflicted!r}'
+                    )
 
         getlogger().debug(f'  > Loaded {len(final_tests)} test(s)')
         return final_tests
